%% COMPUTE FORCING %%
%
% Compute the forcing term for multiple values of the surface tension S.
% Choose the value of S that gives the minimum maximum value of the forcing
% term
%
% Convert measured displacement to the frequency domain. Estimate the
% forcing from this. Then invert to obtain the forcing in the time domain.
% Use this to simulate the displacement. See how this compares with the
% observations.

set(0,'DefaultLineLineWidth',1);
set(0,'DefaultAxesFontSize',16);

%% Displacement data
% Load data and convert from time domain to frequency domain

% load data
load xdisp; % load displacement data into x
x = xdisp;
t = linspace(0, 3, 600); % create time vector

% convert to frequency domain
[f, X, X2, Xparams] = FourierTransform(t, x);
omega = 2*pi*f;
omega2 = [omega -fliplr(omega(1:end-1))];

%% Compute forcing
% Estimate the forcing in the frequency domain from the displacement
% measurements in the frequency domain

% set parameters for modeling
params.rho_infty = 1000; % ambient density of water [kg/m^3]
params.c_infty = 1482; % speed of sound in water [m/s]
p_atmo = 1e5; % atmospheric pressure [Pa]
depth = 18.6; % depth of whale [m]
g = 9.8; % gravitational acceleration [m/s^2]
params.p_infty = p_atmo + params.rho_infty*g*depth; % ambient pressure at depth [Pa]
params.k = 1.4; % polytropic index. Adiabatic = 1.4
params.S = 7.5e4; % surface tension [N/m or kg/s^2]

% solve for equilibrium properties of lung at depth
V_atmo = 1.54; % volume of lungs at surface [m^3]
T_atmo = 293.15; % air temperature at surface [K]
T0 = 310.15; % whale body temperature at depth [K]
Q = 8.314; % universal gas constant [J/(mol K)]
n = p_atmo*V_atmo / (Q*T_atmo); % number of moles of air [mol]
params.R0 = fzero(@(R) R^3*params.p_infty + 2*params.S*R^2 - (n*Q*T0)/(4/3*pi), ...
    3*V_atmo/(4*pi));
params.p0 = params.p_infty + 2*params.S/params.R0;

Smin = 1e2;
Smax = 0.5e6;
Snum = 100;
Svalues = linspace(Smin, Smax, Snum); % values of surface tension [N/m or kg/s^2]
%Svalues = 8e4;
FAmp = zeros(size(Svalues)); % vector to save maximum value of forcing 

% parameters for inverse Fourier Transform
Fparams.tEnd = t(end);
Fparams.dt = 1e-3;
tTmp = min(t):Fparams.dt:max(t);
Fparams.L = length(tTmp);
Fparams.Fs = 1/Fparams.dt+1;
Fparams.Ts = 1/Fparams.Fs;

for i = 1:length(Svalues)
    params.S = Svalues(i); % surface tension [N/m or kg/s^2]
    params.p0 = params.p_infty + 2*params.S/params.R0; % equilibrium pressure [Pa]

    % compute forcing term
    F2 = params.rho_infty .* X2 .* ( -omega2.^2*params.R0 + ...
        (params.p0*3*params.k)/(params.rho_infty*params.R0) - ...
        (2*params.S)/(params.rho_infty*params.R0^2) + ...
        (1i*omega2*3*params.k*params.p0)/(params.rho_infty*params.c_infty) );
    
    % mute values of the forcing above 40 Hz
    for j = 1:length(omega2)
        if abs(omega2(j)) > 40*pi*2
            F2(j) = 0;
        end
    end
    
    % invert forcing from frequency to time domain
    [tinv, finv] = inverseFourierTransform(F2, Fparams);
    
    % set the forcing equal to zero outside the interval of the calling
    ta = 1.4;
    tb = 2.4;
    for k = 1:length(tinv)
        if tinv(k) < ta || tinv(k) > tb
            finv(k) = 0;
        end
    end
      
    % find maximum amplitude of forcing 
    FAmp(i) = sum(real(finv).^2);
    
end

figHandle = figure; clf;
set(figHandle,'Position',[100 100 600 300])

% subplot(2,1,1);
% plot(Svalues, FAmp);
% xlabel('Surface Tension (N/m)');
% ylabel('$\sum \sigma^2$','Interpreter','latex');

% find minimum value of S

[XMAX,IMAX,XMIN,IMIN] = extrema(FAmp);
Smin = Svalues(IMIN);

% compute forcing for this value of S

params.S = Smin; % surface tension [N/m or kg/s^2]
params.p0 = params.p_infty + 2*params.S/params.R0; % equilibrium pressure [Pa]

% compute forcing term
F2 = params.rho_infty .* X2 .* ( -omega2.^2*params.R0 + ...
    (params.p0*3*params.k)/(params.rho_infty*params.R0) - ...
    (2*params.S)/(params.rho_infty*params.R0^2) + ...
    (1i*omega2*3*params.k*params.p0)/(params.rho_infty*params.c_infty) );

% mute values of the forcing above 40 Hz
for j = 1:length(omega2)
    if abs(omega2(j)) > 40*pi*2
        F2(j) = 0;
    end
end

% invert forcing from frequency to time domain
[tinv, finv] = inverseFourierTransform(F2, Fparams);

% set the forcing equal to zero outside the interval of the calling
ta = 1.4;
tb = 2.4;
for k = 1:length(tinv)
    if tinv(k) < ta || tinv(k) > tb
        finv(k) = 0;
    end
end

%subplot(2,1,2);
plot(tinv, real(finv));
xlabel('Time (s)');
ylabel('\sigma (N/m^2)')

print('drivingForce','-dpdf');
