function dYdt = governingEqnLinearForcing(t, Y, params)
% dYdt = governingEqn(t, Y, params)
%
% Linear form of governing equation
%
% Governing equation for whale lung. Modified Herring equation with surface
% tension and a time varying forcing term. Neglect heat transfer (assume
% that the lung expands and contracts adiabatically) and assume no mass
% flow into or out of the lung. Start the system in equilibrium and perturb
% through the time varying forcing term. This term should allow for the
% resonant frequency to vary as a function of time.


% load variable values
R = Y(1); % radius of lung [m]
U = Y(2); % velocity of lung [m/s]

% load parameter values
rho_infty = params.rho_infty; % ambient density [kg/m^3] 
c_infty = params.c_infty; % speed of sound in water [m/s]
S = params.S; % surface tension [N/m or kg/s^2]
k = params.k; % polytropic index. Adiabatic = 1.4

p0 = params.p0; % equilibrium pressure [Pa]
R0 = params.R0; % equilibrium radius [m]

% compute forcing
force = ppval(params.pp, t);

% update variables
dRdt = U;

dUdt = 1/R0 * ( -(p0*3*k*R)/(rho_infty*R0) - (3*k*p0*U)/(rho_infty*c_infty) + ...
    force/params.rho_infty + (2*S*R)/(rho_infty*R0^2) );

dYdt = [dRdt; dUdt];